"use strict";
exports.__esModule = true;
var Mime = require("mime");
var ControllerDto_1 = require("./Controller/ControllerDto");
var Controller = /** @class */ (function () {
    function Controller(request, response, next) {
        if (request === void 0) { request = null; }
        if (response === void 0) { response = null; }
        if (next === void 0) { next = null; }
        this.logger = console;
        this.maxExecutionTime = 0;
        this.init(request, response, next);
    }
    Controller.setDefaultTimeLimit = function (defaultMaxExecutionTime) {
        console.log("defaultMaxExecutionTime", defaultMaxExecutionTime);
        this.defaultMaxExecutionTime = defaultMaxExecutionTime;
    };
    Controller.prototype.setContentType = function (extname) {
        this.response.set("Content-Type", Mime.getType(extname));
    };
    Controller.prototype.getParam = function (name, defaultValue) {
        return this.request.params[name];
    };
    /**
     * 获取get参数
     */
    Controller.prototype.getQuery = function (query, defaultValue) {
        if (defaultValue === void 0) { defaultValue = null; }
        return this.request.query[query] ? this.request.query[query] : defaultValue;
    };
    /**
     * 获取post参数
     */
    Controller.prototype.getPost = function (query, defaultValue) {
        if (defaultValue === void 0) { defaultValue = null; }
        return this.request.body[query] ? this.request.body[query] : defaultValue;
    };
    /**
     * 获取cookie
     */
    Controller.prototype.getCookie = function (cookieName, defaultValue) {
        return this.request.cookies[cookieName] ? this.request.cookies[cookieName] : defaultValue;
    };
    /**
     * 获取整个cookies
     */
    Controller.prototype.getCookies = function () {
        return this.request.cookies;
    };
    /**
     * 设置cookie
     */
    Controller.prototype.setCookie = function (name, val, options) {
        this.response.cookie(name, val, options);
    };
    /**
     * 清除cookie
     * @param name
     * @param options
     */
    Controller.prototype.clearCookie = function (name, options) {
        this.response.clearCookie(name, options);
    };
    /**
     * 重定向访问
     */
    Controller.prototype.redirect = function (url) {
        this.response.redirect(url);
    };
    /**
     * @deprecated 过时了方法，请使用setCORS
     */
    Controller.prototype.setOrigin = function () {
        var origin = this.request.header("Origin");
        if (typeof origin === "string") {
            if (this.origin.includes(origin.replace(/https\:\/\/|http\:\/\//, ""))) {
                this.response.set("Access-Control-Allow-Origin", origin);
            }
        }
    };
    /**
     * 配置某个接口的跨域规则，一次请求只能使用一次！
     * @param originRegex 跨域规则
     */
    Controller.prototype.setCORS = function (originRegex) {
        if (originRegex === void 0) { originRegex = /\.(?:mtime|test)\.(?:cn|com)/; }
        var origin = this.request.header("Origin");
        if (originRegex.test(origin)) {
            this.response.set("Access-Control-Allow-Origin", origin);
        }
        return this;
    };
    /**
     * 发送buffer
     */
    Controller.prototype.sendBuffer = function (buf) {
        this.send(buf);
    };
    /**
     *
     * @param buf
     */
    Controller.prototype.sendDownload = function (buf) {
        this.send(buf);
    };
    /**
     *
     * @param json
     */
    Controller.prototype.sendJSONP = function (json, statusCode) {
        if (statusCode === void 0) { statusCode = ControllerDto_1.E_STATUS_CODE.NORMAL; }
        this.response.status(statusCode);
        this.response.jsonp(json);
    };
    /**
     *
     * @param mime
     */
    Controller.prototype.setMIME = function (mime) {
        this.response.set("mimie", mime);
    };
    /**
     * ok
     * @param responseJSON
     */
    Controller.prototype.ok = function (responseJSON) {
        responseJSON.ok = true;
        this.sendJSON(responseJSON);
    };
    /**
     *
     * @param content
     * @param statusCode
     */
    Controller.prototype.sendJSON = function (content, statusCode) {
        if (statusCode === void 0) { statusCode = ControllerDto_1.E_STATUS_CODE.NORMAL; }
        if (typeof content === "undefined") {
            this.logger.error(new Error("content"), content);
            throw new Error("CAN_NOT_SEND_UNDEFINED");
        }
        if (typeof content !== "object") {
            throw new Error("IS_NOT_OBJECT");
        }
        else {
            try {
                if (Object.keys(content).length < 0) {
                    this.logger.error("Controller", "sendJSON", "content", content);
                    throw new Error("OBJECT_IS_EMPTY");
                }
            }
            catch (error) {
                this.logger.error("Controller", "sendJSON", "content", error);
                throw new Error("IS_NOT_OBJECT");
            }
        }
        if (this.response.headersSent) {
            this.logger.error("警告：重复发送header", this.request.originalUrl);
        }
        else {
            this.response.status(statusCode);
            this.response.json(content);
        }
    };
    /**
     *
     * @param html
     */
    Controller.prototype.sendHTML = function (html) {
        this.send(html);
    };
    /**
     * @deprecated 过时的方法，请使用sendJSON
     * @param content
     */
    Controller.prototype.json = function (content) {
        this.sendJSON(content);
    };
    /**
     * 发送
     * @param content
     */
    Controller.prototype.send = function (content) {
        if (this.response.headersSent) {
            this.logger.error("警告：重复发送header", this.request.originalUrl);
        }
        else {
            this.response.send(content);
        }
    };
    Controller.prototype.isSend = function () {
        return this.response.headersSent;
    };
    Controller.prototype.isXHR = function () {
        return this.request.xhr;
    };
    /**
     * 配置超时时间
     * @param maxExecutionTime 超时时间，为0永不超时
     */
    Controller.prototype.setTimeLimit = function (maxExecutionTime) {
        this.maxExecutionTime = maxExecutionTime;
    };
    Controller.prototype.getTimeLimit = function () {
        return this.maxExecutionTime;
    };
    Controller.prototype.init = function (request, response, next) {
        this.request = request;
        this.response = response;
        this.next = next;
        if (request !== null) {
            this.setTimeLimit(Controller.defaultMaxExecutionTime);
        }
    };
    Controller.defaultMaxExecutionTime = 0;
    return Controller;
}());
exports.Controller = Controller;
//# sourceMappingURL=Controller.js.map